import { defineStore } from "pinia";
import { getDictByCode, getUserFormRole, getRegion, getProductType, getCapital } from "@/api/dict"
import { findAllOrg } from '@/api/dataSource/m3Manage'
import { strFirstUpper, treeChildrenEmpty, treeLabelValue } from "@/utils/index"
import constantData from './constantData'

export const useDictStore = defineStore({
  id: 'DictStroe',
  state: () => {
    return {
      noConstant: ['regionList', 'departmentList', 'productType', 'capitalList'],
      tree: [],
      noCache: [],
      params: ['roleUserList', 'capitalList'],
      constant: {
        ...constantData, // 前端维护的常量数据
        regionList: [],
        roleUserList: [], // 角色下用户
        code: [],
        reportType: [], // 财务报表-报表类型
        companyOwnership: [], // 财务报表-公司主体
        factoringProductsExport: [], // M3-产品类型-境外
        factoringProductsDomestic: [], // M3-产品类型-境内
        currencyType: [], // M3-产品类型-币种
        assetType: [], // M3-资产类型 | 资金类型 | 资产类型
        captialList: [], // 资本公积金-资方
        rateType: [], // 自有资金成本利率-利率类型
        annualReportType: [], // 年度设定-年度目标-报表类型
        departmentList: [],   // 所属部门
        productType: [], // 产品类型
        capitalList: [], // 资方 - 获取所有的资方
        payBackMethod: [], // 还款方式
        incormeExpenditureType: [], // 金额类型
        marginType: [], // 保证金类型 | 保证金类别
        productTypeDetail: [] // 产品名称详情
      }
    }
  },

  actions: {
    getConstant(name) {
      const events = []
      const isConstant = name => {
        if (this.noConstant.includes(name)) {
          events.push(this[`get${strFirstUpper(name)}`](name))
        } else if (this.tree.includes(name)) {
          // events.push(dispatch('getTreeDict', name))
        } else if (typeof (name) === 'object' && this.params.includes(name.type)) {
          events.push(this[`get${strFirstUpper(name.type)}`](name))
        } else {
          events.push(this['getDict'](name))
        }
      }
      if (Array.isArray(name)) {
        for (const item of name) {
          var type = typeof (item) === 'object' ? item.type : item
          if (!this.noCache.includes(type)) {
            const constantType = Object.prototype.toString.call(this.constant[type])
            if (constantType === '[object Array]') {
              if (this.constant[type]?.length) continue
            } else if (constantType === '[object Object]') {
              if (Object.keys(this.constant[type]).length) continue
            } else if (constantType === '[object String]') {
              if (this.constant[type]) continue
            }
          }
          isConstant(item)
        }
      } else {
        var typeStrTemp = typeof (name) === 'object' ? name.type : name
        if (!this.noCache.includes(typeStrTemp)) {
          if (!this.noCache.includes(typeStrTemp)) {
            const typeStr = Object.prototype.toString.call(this.constant[typeStrTemp])
            if (typeStr === '[object Array]') {
              if (this.constant[typeStr].length) return
            } else if (typeStr === '[object Object]') {
              if (Object.keys(this.constant[typeStr]).length) return
            } else if (typeStr === '[object String]') {
              if (this.constant[typeStr]) return
            }
          }
        }
        isConstant(name)
      }
      return Promise.all(events)
    },
    getDict(code) {
      return new Promise((resolve, reject) => {
        getDictByCode({ code }).then((res: AxiosResponseRes) => {
          if (res.data) {
            if (code in this.constant) {
              this.constant[code] = res.data
            }
            resolve(res.data)
          }
        }).catch(error => {
          reject(error)
        })
      })

    },
    getRoleUserList(params) {
      return new Promise((resolve, reject) => {
        getUserFormRole(params.query).then((res: AxiosResponseRes) => {
          this.constant[params.type] = res.data
          resolve(res.data)
        }).catch(error => {
          reject(error)
        })
      })
    },
    getRegionList(type) {
      return new Promise((resolve, reject) => {
        getRegion().then((res: AxiosResponseRes) => {
          const list = treeChildrenEmpty(res.data)
          treeLabelValue(list, { value: 'deptCode', label: 'name' })
          this.constant[type] = res.data
          resolve(res.data)
        }).catch(error => {
          reject(error)
        })
      })
    },
    getDictName(code, val) {
      if (!this.constant[code]) return ''
      if (this.constant[code].length === 0) return ''
      return this.constant[code].find(el => el.code === val) ? this.constant[code].find(el => el.code === val).name : this.constant[code].find(el => el.code === String(val)).name
    },
    getDepartmentList(type) {
      return new Promise((resolve, reject) => {
        findAllOrg().then((res: AxiosResponseRes) => {
          this.constant[type] = res.data
          resolve(res.data)
        }).catch(error => {
          reject(error)
        })
      })
    },
    getProductType(type) {
       return new Promise((resolve, reject) => {
        getProductType().then((res: AxiosResponseRes) => {
          this.constant[type] = res.data
          resolve(res.data)
        }).catch(error => {
          reject(error)
        })
      })
    },
    getCapitalList({ type, query }) {
      return new Promise((resolve, reject) => {
        getCapital(query).then((res: AxiosResponseRes) => {
          this.constant[type] = res.data
          resolve(res.data)
        }).catch(error => {
          reject(error)
        })
      })
    }
  },
})
