import { defineStore } from "pinia";
import { store } from "@/store";
import { cacheType } from "./types";
import { constantMenus, baseMenus } from "@/router";
import { useMultiTagsStoreHook } from "./multiTags";
import { useUserStoreHook  } from "./user";
import { debounce, getKeyList } from "@pureadmin/utils";
import { ascending, filterTree, filterNoPermissionTree, filterTreeData } from "@/router/utils";
import { setSessionStorage } from "@/utils/auth";

// 过滤树


export const usePermissionStore = defineStore({
  id: "pure-permission",
  state: () => ({
    // 基础路由
    baseMenus,
    // 静态路由生成的菜单
    constantMenus,
    // 整体路由生成的菜单（静态、动态）
    wholeMenus: [],
    // 缓存页面keepAlive
    cachePageList: [],
    // 异步路由生成的菜单
    asyncMenus: [],
  }),
  actions: {
    /** 组装整体路由生成的菜单 */
    handleWholeMenus(routes: any[]) {
      this.wholeMenus = filterNoPermissionTree(
        filterTree(ascending(this.baseMenus.concat(routes)))
      );
    },
    cacheOperate({ mode, name }: cacheType) {
      const delIndex = this.cachePageList.findIndex(v => v === name);
      switch (mode) {
        case "refresh":
          this.cachePageList = this.cachePageList.filter(v => v !== name);
          break;
        case "add":
          this.cachePageList.push(name);
          break;
        case "delete":
          delIndex !== -1 && this.cachePageList.splice(delIndex, 1);
          break;
      }
      /** 监听缓存页面是否存在于标签页，不存在则删除 */
      debounce(() => {
        let cacheLength = this.cachePageList.length;
        const nameList = getKeyList(useMultiTagsStoreHook().multiTags, "name");
        while (cacheLength > 0) {
          nameList.findIndex(v => v === this.cachePageList[cacheLength - 1]) ===
            -1 &&
            this.cachePageList.splice(
              this.cachePageList.indexOf(this.cachePageList[cacheLength - 1]),
              1
            );
          cacheLength--;
        }
      })();
    },
    /** 清空缓存页面 */
    clearAllCachePage() {
      this.wholeMenus = [];
      this.cachePageList = [];
    },
    generateRoutes(routes) {
      return new Promise((resolve, reject) => {
        useUserStoreHook().getPermission().then(({ buttons, menus }) => {
          setSessionStorage('buttons', JSON.stringify(buttons))
          setSessionStorage('menus', JSON.stringify(menus))
          const routerList = filterTreeData(routes, menus)
          this.asyncMenus = routerList
          resolve(routerList)
        }).catch(error => {
          reject(error)
        })
      })
    },

  }
});

export function usePermissionStoreHook() {
  return usePermissionStore(store);
}
