/**
 * 格式化时间
 * @param {(Object|string|number)} time
 * @param {string} cFormat
 * @returns {string | null}
 */
export function parseTime(time, cFormat) {
  if (arguments.length === 0 || !time) {
    return null
  }
  const format = cFormat || 'y-m-d h:i:s'
  let date
  if (typeof time === 'object') {
    date = time
  } else {
    if (('' + time).length === 10) time = parseInt(time) * 1000
    date = new Date(time)
  }
  const formatObj = {
    y: date.getFullYear(),
    m: date.getMonth() + 1,
    d: date.getDate(),
    h: date.getHours(),
    i: date.getMinutes(),
    s: date.getSeconds(),
    a: date.getDay()
  }
  const time_str = format.replace(/(y|m|d|h|i|s|a)/g, (result, key) => {
    let value = formatObj[key]
    // Note: getDay() returns 0 on Sunday
    if (key === 'a') {
      return ['日', '一', '二', '三', '四', '五', '六'][value]
    }
    if (result.length > 0 && value < 10) {
      value = '0' + value
    }
    return value || 0
  })
  return time_str
}


/**
 * 根据子集查找父集
 * @params tree tree树形数据
 * @param checkName 查找值
 * @param optionName 查找字段
 * @param childName 子集key
 * @param targetName 指向的值
 *
 *  */
export function queryParent<T, O>(tree: T, checkName: O, optionName:string, childName:string = 'children', targetName:string = '') {
  const level = [];
  (function queryParent(data, checkName, parent) {
    Array.isArray(data) &&
    data.forEach((item, index) => {
      if (item[optionName] !== checkName) {
        item[childName] && queryParent(item[childName], checkName, [data, index])
      } else {
        parent && queryParent(tree, parent[0][parent[1]][optionName])
        level.push(targetName === '' ? item[optionName] : item[targetName])
      }
    })
  })(tree, checkName)
  return level
}

// 字符串首字母大写
export const strFirstUpper = str =>
  str.replace(/( |^)[a-z]/g, first => first.toUpperCase())

// 处理tree children为空的情况
export function treeChildrenEmpty(tree, type = 'children') {
  return tree.map(item => {
    if (item[type] && item[type].length !== 0) {
      treeChildrenEmpty(item[type], type)
    } else {
      delete item[type]
    }
    return item
  })
}

// 处理tree label 和 value
export function treeLabelValue(tree, options, type = 'children') {
  tree.forEach(item => {
    const { label, value } = options
    if (item[type] && item[type].length) {
      treeLabelValue(item[type], options, type)
    }
    item.label = item[label]
    item.value = item[value]
  })
}

// 导出附件
export function exportFile(res, name?) {
  if (!res.data) return
  const url = window.URL.createObjectURL(new Blob([res.data]))
  const link = document.createElement('a')
  link.style.display = 'none'
  link.href = url
  // 获取文件的名字
  var newName = ''
  var filename = res.headers
  filename = filename['content-disposition']
  filename = filename.split(';')[1].split('filename=')[1]
  newName = decodeURI(filename)
  link.setAttribute(
    'download',
    name || newName
  )
  document.body.appendChild(link)
  link.click()
  document.body.removeChild(link)
}

// 千分位分割
export function forMatMoney(money) {
  if (!money || Number.isNaN(money)) return ''
  return String(money).replace(/\B(?=(\d{3})+(?!\d))/g, ',')
}

// 判断字段是 '', null, undefined
export function isEmpty(val) {
  return val === '' || val === null || val === undefined
}


/**
 * 字典数据把code转换成name
 * @params list list数据
 * @params code 所传的code值
 * @params codeType 查找的list对应的类型 例如 id或者code
 * @params type 返回list中所对应的值
 * */
export function codeChangeName(list, code, codeType = 'code', type = 'name') {
  if (Array.isArray(list)) {
    const row = list.filter(item => (item[codeType] === code))
    if (row.length) {
      return row[0][type]
    }
  }
}
