import { ref, computed } from 'vue'
import { useRouter } from 'vue-router'
import { forMatMoney } from '@utils'

export function useColumns(search) {
  const router = useRouter()
  const columns: TableColumnList = [
    // {
    //   type: 'selection',
    // },
    {
      label: '序号',
      type: 'index',
      width: 55,
    },
    {
      label: '业务编号',
      prop: 'businessNo',
      showOverflowTooltip: true
    },
    {
      label: '客户名称',
      prop: 'customerName',
      showOverflowTooltip: true
    },
    {
      label: '合同编号',
      prop: 'contractNo',
      showOverflowTooltip: true
    },
    {
      label: '支用批次',
      prop: 'quotaDisburseBatch',
      showOverflowTooltip: true
    },
    {
      label: '币种',
      prop: 'currency',
      showOverflowTooltip: true
    },
     {
      label: '合同本金',
      prop: 'contractAmount',
      showOverflowTooltip: true,
      cellRenderer: ({ row }) => {
        return forMatMoney(row.contractAmount)
      }
    },
    {
      label: '项目经理',
      prop: 'projectManagerName',
      showOverflowTooltip: true
    },
    {
      label: '产品类型',
      prop: 'productType',
      showOverflowTooltip: true
    },
    {
      label: '合同计划投放日期',
      prop: 'contractPlanDeliveryDate',
      showOverflowTooltip: true,
      width: 140
    },
     {
      label: '合同计划到期日',
      prop: 'contractPlanExpiryDate',
      showOverflowTooltip: true,
      width: 130
    },
    {
      label: '操作',
      width: '100',
      cellRenderer: ({ index, row }) => {
        const btnList = [
          {
            msg: '明细',
            icon: 'text-customPurple iconfont icon-watch',
            power: '',
            category: 'see'
          },
          {
            msg: '修正',
            icon: 'text-customPurple iconfont icon-edit',
            power: 'modifyBusinessStandingBook',
            tabPower: ['all'],
            category: 'edit'
          },
        ]
        const options = btnList.map(item => {
          return (
            <el-tooltip effect='dark' content={item.msg} placement='top' >
              <i class={item.icon} v-power={ item.power } onClick={() => { handlerOperate(item.category, row) } }></i>
            </el-tooltip>
          )
        })
        return <>
         { options }
        </>
      }
    }
  ]

  const tablePower = ({ item, tab, row }) => {
    const { tabPower, rowPower } = item
    if (rowPower) {

    } else {
      if (tabPower.includes(tab)) {
        return true
      } else {
        return false
      }
    }
  }

  const tableData = ref<any[]>([])
  const total = ref<number>(0)

  const handleSelectionChange = (val) => {
    console.log(val, 11111111)
  }

  const handlerOperate = (type, row) => {
    const { id } = row
    switch (type) {
      case 'edit':
        router.push({ path: '/businessLedgerDetails', query: { id, type: 'edit' }})
        break;
      case 'see':
        router.push({ path: '/businessLedgerDetails', query: { id, type: 'see' }})
        break;
      default:
        break;
    }
  }
  return {
    columns,
    tableData,
    total,
    handleSelectionChange
  }
}
