import { ref } from "vue"
import Decimal from 'decimal.js'

export function useFinancialColumns(feildsDisabled?) {

  const staticColumns = ref<any[]>([
    {
      feeName: '手续费',
      amount: '',
      rowDisabled: false
    },
    {
      feeName: '汇兑损益',
      amount: '',
      rowDisabled: false
    },
    {
      feeName: '利息支出',
      amount: '',
      rowDisabled: false
    },
    {
      feeName: '利息收入',
      amount: '',
      rowDisabled: false
    },
    {
      feeName: '合计',
      amount: 0,
      rowDisabled: true
    },
  ])

  const financialTableData = ref<any[]>([
    {
      feeName: '手续费',
      amount: '',
      rowDisabled: false
    },
    {
      feeName: '汇兑损益',
      amount: '',
      rowDisabled: false
    },
    {
      feeName: '利息支出',
      amount: '',
      rowDisabled: false
    },
    {
      feeName: '利息收入',
      amount: '',
      rowDisabled: false
    },
    {
      feeName: '合计',
      amount: 0,
      rowDisabled: true
    },
  ])

  const amountFeildChange = (val) => {
    let sum = new Decimal(0);
    financialTableData.value.forEach((el) => {
      if (el.feeName !== '合计') {
        sum = sum.plus(new Decimal(el.amount === '' ? 0 : el.amount))
      }
    })

    financialTableData.value[financialTableData.value.length - 1].amount = sum
  }

  const financialColumns = ref<TableColumnList>([
    {
      label: '费用名称',
      prop: 'feeName',
      showOverflowTooltip: true,
    },
    {
      label: '金额',
      showOverflowTooltip: true,
      cellRenderer: ({ index, row }) => (
        <>
          <cy-amount-input v-model={row.amount} onChange={ amountFeildChange } disabled={ row.rowDisabled || feildsDisabled }></cy-amount-input>
        </>
      )
    }
  ])

  const setFinancialTable = (fillObj) => {
    if (financialTableData.value.length == 0) {
      financialTableData.value = staticColumns.value
    }
    if (fillObj && Object.keys(fillObj).length) {
      const fillFeilds = ['handlingFees', 'exchangeGainsLosses', 'interestExpenses', 'interestIncome'] // 这里值跟financialTableData回填顺序是一致的
      let start = 0
      while (start < fillFeilds.length) {
        financialTableData.value[start].amount = fillObj[fillFeilds[start]]
        start++
      }
      // 合计
      financialTableData.value[financialTableData.value.length - 1].amount = fillObj.totalAmount
    }
  }

  // 当前表格生成对对象的形式
  const genneratorFinancial = () => {
    const res: any = {}
    const fillFeilds = ['handlingFees', 'exchangeGainsLosses', 'interestExpenses', 'interestIncome']
    let start = 0
    while (start < fillFeilds.length) {
      res[fillFeilds[start]] = financialTableData.value[start].amount
      start++
    }
    // 合计默认都在最后一项单独赋值
    res.totalAmount = financialTableData.value[financialTableData.value.length - 1].amount
    return res
  }

  return {
    financialColumns,
    financialTableData,
    setFinancialTable,
    genneratorFinancial
  }
}
