import { ref } from "vue"
import Decimal from 'decimal.js'

export function useTaxFeeColumns(feildsDisabled?) {

  const staticColumns = ref<any[]>([
    {
      feeName: '增值税',
      amount: '',
      rowDisabled: false
    },
    {
      feeName: '所得税',
      amount: '',
      rowDisabled: false
    },
    {
      feeName: '附加税',
      amount: '',
      rowDisabled: false
    },
    {
      feeName: '房产土地税',
      amount: '',
      rowDisabled: false
    },
    {
      feeName: '合计',
      amount: 0,
      rowDisabled: true
    },
  ])

  const taxFeeTableData = ref<any[]>([
    {
      feeName: '增值税',
      amount: '',
      rowDisabled: false
    },
    {
      feeName: '所得税',
      amount: '',
      rowDisabled: false
    },
    {
      feeName: '附加税',
      amount: '',
      rowDisabled: false
    },
    {
      feeName: '房产土地税',
      amount: '',
      rowDisabled: false
    },
    {
      feeName: '合计',
      amount: 0,
      rowDisabled: true
    },
  ])

  const amountFeildChange = (val) => {
    let sum = new Decimal(0);
    taxFeeTableData.value.forEach((el) => {
      if (el.feeName !== '合计') {
        sum = sum.plus(new Decimal(el.amount === '' ? 0 : el.amount))
      }
    })

    taxFeeTableData.value[taxFeeTableData.value.length - 1].amount = sum
  }

  const taxFeeColumns = ref<TableColumnList>([
    {
      label: '费用名称',
      prop: 'feeName',
      showOverflowTooltip: true,
    },
    {
      label: '金额',
      showOverflowTooltip: true,
      cellRenderer: ({ index, row }) => (
        <>
          <cy-amount-input v-model={row.amount} onChange={ amountFeildChange } disabled={ row.rowDisabled || feildsDisabled }></cy-amount-input>
        </>
      )
    }
  ])

  const setTaxFeeTable = (fillObj) => {

    if (taxFeeTableData.value.length == 0) {
      taxFeeTableData.value = staticColumns.value
    }

    if (fillObj && Object.keys(fillObj).length) {
      const fillFeilds = ['valueAddedTax', 'incomeTax', 'additionalTax', 'propertyLandTax'] // 固定值回填不包含合计
      let start = 0
      while (start < fillFeilds.length) {
        taxFeeTableData.value[start].amount = fillObj[fillFeilds[start]]
        start++
      }
      // 合计
      taxFeeTableData.value[taxFeeTableData.value.length - 1].amount = fillObj.totalAmount
    }
  }

  // 当前表格生成对对象的形式
  const genneratorTaxFee = () => {
    const res: any = {}
    const fillFeilds = ['valueAddedTax', 'incomeTax', 'additionalTax', 'propertyLandTax']
    let start = 0
    while (start < fillFeilds.length) {
      res[fillFeilds[start]] = taxFeeTableData.value[start].amount
      start++
    }
    // 合计默认都在最后一项单独赋值
    res.totalAmount = taxFeeTableData.value[taxFeeTableData.value.length - 1].amount
    return res
  }

  return {
    taxFeeColumns,
    taxFeeTableData,
    setTaxFeeTable,
    genneratorTaxFee
  }
}
