import { ref, computed } from 'vue'
import { useCurrency } from '@/views/dataSource/m3Manage/hook/index'
import { findUserByOrgId } from "@/api/dataSource/m3Manage"

export const requiredFeilds = ['projectName', 'orgId', 'costAmount', 'currency', 'abstractStr']


export function useColumns(...args) {
  const [ownerOrgList, feildsDisabled] = args
  const tableData = ref<any[]>([])

  const currencyList = computed(() => {
    return useCurrency().currencyTypeList.value
  })

  const columns: TableColumnList = [
    {
      label: '项目名称',
      showOverflowTooltip: true,
      cellRenderer: ({ index, row }) => (
        <>
          <el-input v-model={ row.projectName } disabled={ feildsDisabled } />
        </>
      )
    },
    {
      label: '所属部门',
      showOverflowTooltip: true,
      cellRenderer: ({ index, row }) => (
        <>
          <el-select
            v-model={row.orgId}
            clearable
            placeholder="请选择所属部门"
            onChange={(val) => { orgListChange(row, val) } }
          >
            {
              ownerOrgList.value.map(org => (
                <el-option key={org.id} label={org.name} value={org.id} />
              ))
            }
          </el-select>
        </>
      )
    },
    {
      label: '项目经理',
      showOverflowTooltip: true,
      cellRenderer: ({ index, row }) => (
        <>
          <el-select
            v-model={row.projectManager}
            clearable
            placeholder="请选择项目经理"
          >
            {
              row.projectManagerList.map(item => (
                <el-option key={item.id} label={item.name} value={item.id} />
              ))
            }
          </el-select>
        </>
      )
    },
    {
      label: '金额',
      showOverflowTooltip: true,
      cellRenderer: ({ index, row }) => (
        <>
          <cy-amount-input v-model={ row.costAmount } disabled={ feildsDisabled } ></cy-amount-input>
        </>
      )
    },
    {
      label: '币种',
      cellRenderer: ({ index, row }) => (
        <>
          <el-select
            v-model={row.currency}
            clearable
            placeholder="请选择币种"
          >
            {
              currencyList.value.map(item => (
                <el-option key={item.code} label={item.name} value={item.code} />
              ))
            }
          </el-select>
        </>
      )
    },
    {
      label: '摘要',
      showOverflowTooltip: true,
      cellRenderer: ({ index, row }) => (
        <>
          <el-input v-model={ row.abstractStr } disabled={ feildsDisabled } />
        </>
      )
    },
  ]

    const orgListChange = (row, val) => {
      if (row) {
        row.projectManager = ''
        getProjectManager(val, row)
      }
    }

  const getProjectManager = (orgId: string, row: any) => {
    if (orgId) {
      findUserByOrgId({ orgId }).then((res: AxiosResponseRes) => {
        row.projectManagerList = res.data
      })
    }
  }

  return {
    tableData,
    columns,
  }
}
