import { ref, watchEffect } from 'vue'
export const assetsRequiredFeilds = ['货币资金', '应收账款', '预付款项', '其他应收款', '流动资产合计', '固定资产', '资产总计']

export const debtRequiredFeilds = ['短期借款', '预收款项', '应付利息', '其他应付款', '流动负债合计', '长期借款', '负债合计', '实收资本（或股本）', '资本公积', '所有者权益（或股东权益）合计']

export function useAssetsColumns(feildsDisabled?) {
  const assetsTableData = ref<any[]>([])
  const debtTableData = ref<any[]>([])

  // 资产负债表格
  const assetsColumns: TableColumnList = [
    {
      label: '资产',
      width: 120,
      showOverflowTooltip: true,
      cellRenderer: ({ index, row }) => (
        <>
          {
            assetsRequiredFeilds.includes(row.assetLiabilities?.trim()) ?
            <span>
              <span style='color: red'>*</span>
              {row.assetLiabilities?.trim()}
              </span>
              :
            <span>
              {row.assetLiabilities?.trim()}
            </span>
          }
        </>
      )
    },
    {
      label: '期末余额',
      showOverflowTooltip: true,
      cellRenderer: ({ index, row }) => (
        <>
          <cy-amount-input v-model={ row.closingBalance } disabled={ feildsDisabled }></cy-amount-input>
        </>
      )
    },
    {
      label: '年初余额',
      showOverflowTooltip: true,
      cellRenderer: ({ index, row }) => (
        <>
          <cy-amount-input v-model={ row.openingBalance } disabled={ feildsDisabled } ></cy-amount-input>
        </>
      )
    }
  ]

  const debtColumns: TableColumnList = [
    {
      label: '负债及所有者权益（或股东权益）',
      showOverflowTooltip: true,
      cellRenderer: ({ index, row }) => (
        <>
          {
            debtRequiredFeilds.includes(row.assetLiabilities?.trim()) ?
            <span>
              <span style='color: red'>*</span>
              {row.assetLiabilities?.trim()}
              </span>
              :
            <span>
              {row.assetLiabilities?.trim()}
            </span>
          }
        </>
      )
    },
    {
      label: '期末余额',
      showOverflowTooltip: true,
      cellRenderer: ({ index, row }) => (
        <>
          <cy-amount-input v-model={ row.closingBalance } disabled={ feildsDisabled }></cy-amount-input>
        </>
      )
    },
    {
      label: '年初余额',
      showOverflowTooltip: true,
      cellRenderer: ({ index, row }) => (
        <>
          <cy-amount-input v-model={ row.openingBalance } disabled={ feildsDisabled } ></cy-amount-input>
        </>
      )
    },
  ]

  return {
    assetsTableData,
    assetsColumns,
    debtTableData,
    debtColumns,
  }
}
