import { ref, computed } from 'vue'
import { useProductType } from '../hook/index'
import { findUserByOrgId } from "@/api/dataSource/m3Manage"
import { useDictStore } from '@/store/modules/dict'

export const requiredFeilds = ['projectName', 'orgId', 'assetType', 'incomeAmount', 'currency']


export function useColumns(...args) {
  const [ownerOrgList, feildsDisabled, assetsList, currencyList] = args
  const tableData = ref<any[]>([])
  const projectManagerList = ref<any[]>([])

  const productTypeList = computed(() => {
    return useProductType().productTypeList.value
  })

  const columns: TableColumnList = [
    {
      label: '项目名称',
      width: 120,
      showOverflowTooltip: true,
      // cellRenderer: ({ index, row }) => (
      //   <>
      //     {
      //       assetsRequiredFeilds.includes(row.assetLiabilities?.trim()) ?
      //       <span>
      //         <span style='color: red'>*</span>
      //         {row.assetLiabilities}
      //         </span>
      //         :
      //       <span>
      //         {row.assetLiabilities}
      //       </span>
      //     }
      //   </>
      // )
      cellRenderer: ({ index, row }) => (
        <>
          <el-input v-model={ row.projectName } disabled={ feildsDisabled } />
        </>
      )
    },
    {
      label: '所属部门',
      showOverflowTooltip: true,
      cellRenderer: ({ index, row }) => (
        <>
          <el-select
            v-model={row.orgId}
            clearable
            placeholder="请选择所属部门"
            onChange={(val) => { orgListChange(row, val) } }
          >
            {
              ownerOrgList.value.map(org => (
                <el-option key={org.id} label={org.name} value={org.id} />
              ))
            }
          </el-select>
        </>
      )
    },
    {
      label: '项目经理',
      showOverflowTooltip: true,
      cellRenderer: ({ index, row }) => (
        <>
          <el-select
            v-model={row.projectManager}
            clearable
            placeholder="请选择项目经理"
          >
            {
              row.projectManagerList.map(item => (
                <el-option key={item.id} label={item.name} value={item.id} />
              ))
            }
          </el-select>
        </>
      )
    },
    {
      label: '产品类型',
      showOverflowTooltip: true,
      cellRenderer: ({ index, row }) => (
        <>
          <el-select
            v-model={row.productType}
            clearable
            placeholder="请选择产品类型"
          >
            {
              productTypeList.value.map(item => (
                <el-option key={item.code} label={item.name} value={item.code} />
              ))
            }
          </el-select>
        </>
      )
    },
    {
      label: '资产类型',
      showOverflowTooltip: true,
      cellRenderer: ({ index, row }) => (
        <>
          <el-select
            v-model={row.assetType}
            clearable
            placeholder="请选择产品类型"
          >
            {
              assetsList.map(item => (
                <el-option key={item.code} label={item.name} value={item.code} />
              ))
            }
          </el-select>
        </>
      )
    },
    {
      label: '收入金额',
      showOverflowTooltip: true,
      cellRenderer: ({ index, row }) => (
        <>
          <cy-amount-input v-model={ row.incomeAmount } disabled={ feildsDisabled } ></cy-amount-input>
        </>
      )
    },
    {
      label: '币种',
      cellRenderer: ({ index, row }) => (
        <>
          <el-select
            v-model={row.currency}
            clearable
            placeholder="请选择币种"
          >
            {
              currencyList.map(item => (
                <el-option key={item.code} label={item.name} value={item.code} />
              ))
            }
          </el-select>
        </>
      )
    },
  ]

    const orgListChange = (row, val) => {
      if (row) {
        row.projectManager = ''
        getProjectManager(val, row)
      }
    }

  const getProjectManager = (orgId: string, row: any) => {
    if (orgId) {
      findUserByOrgId({ orgId }).then((res: AxiosResponseRes) => {
        row.projectManagerList = res.data
      })
    }
  }

  return {
    tableData,
    columns,
  }
}
