import { computed, ref } from 'vue'
import { useDictStore } from '@/store/modules/dict'
import { router } from '@/router/index'
import { downloadSingle } from '@/api/dataSource/financialStatement/index'
import { exportFile } from '@/utils'
import { getSessionStorage } from '@/utils/auth'

const powerList = getSessionStorage('buttons') || []

const tablePower = (item?, tab?, row?) => {
    const { tabPower, rowPower, power, satausPower } = item
    if (power && !powerList.includes(power)) {
      return false
    }
    // if (rowPower && (!row.taskName || !rowPower.includes(row.taskName))) {
    //   return false
    // }
    if (satausPower && (!satausPower.includes(row.buttonFlag))) {
      return false
    }
    // if (tabPower && !tabPower.includes(tab)) {
    //   return false
    // }
    return true
  }

export function useColumns(parentFn?:(rows?: any) => void) {
  const columns: TableColumnList = [
    // {
    //   type: 'selection',
    //   width: 50
    // },
    {
      label: '序号',
      type: 'index',
      width: 100
    },
    {
      label: '项目名称',
      prop: 'projectName',
      showOverflowTooltip: true
    },
    {
      label: '所属部门',
      prop: 'org.name',
      showOverflowTooltip: true
    },
    {
      label: '项目经理',
      prop: 'projectManagerName.name',
      showOverflowTooltip: true
    },
    {
      label: '产品类型',
      prop: 'productType',
      showOverflowTooltip: true
    },
    {
      label: '资产类型',
      prop: 'assetType',
      showOverflowTooltip: true
    },
    {
      label: '收入金额',
      prop: 'incomeAmount',
      showOverflowTooltip: true
    },
    {
      label: '币种',
      prop: 'currency',
      showOverflowTooltip: true
    },
    {
      label: '日期',
      prop: 'date',
      showOverflowTooltip: true
    },
    {
    label: "操作",
      cellRenderer: ({ index, row }) => {
        const btnList = [
          // {
          //   msg: '查看',
          //   category: 'see',
          //   power: 'viewFinanceReport'
          // },
          {
            msg: '修改',
            category: 'edit',
            power: 'updateM3Income'
          },
          // {
          //   msg: '下载',
          //   category: 'download',
          //   // power: 'downloadFinanceReport',
          //   satausPower: [true]
          // },
        ]
        const options = btnList.map(item => {
          return tablePower(item, '', row) && (
            <el-tooltip class='item' effect='dark' content={item.msg} placement='top' >
                <span class='table-icon-box' onClick={() => { handleOperate(item.category, row) }}>
                  {/* class={item.icon} */}
                {/* <i onClick={() => { this.handleOperate(item.category, row) }}></i> */}
                {item.msg}
              </span>
            </el-tooltip>
          )
        })
        return (
          <>
            <div>{ options }</div>
          </>
        )
      }
    }
  ]

  const handleOperate = (operateType, row) => {
    if (operateType == 'edit') {
      handleEdit(row)
    }
    if (operateType == 'see') {
      handleWatch(row)
    }
    if (operateType == 'download') {
      handleDownload(row)
    }
  }

  const handleWatch = (rows?) => {
    router.push({
      name: 'FinancialReportDetail',
      query: {
        type: 'see',
        id: rows.id
      }
    })
   }

  const handleEdit = (rows?: any) => {
    // router.push({
    //   name: 'FinancialReportAdd',
    //   query: {
    //     type: 'edit',
    //     id: rows.id
    //   }
    // })
    parentFn && parentFn(rows)
  }

  const handleDownload = async (rows?) => {
    const res: any = await downloadSingle({ id: rows.id })
    exportFile(res)
  }

  const tableData = ref<any[]>([])
  const total = ref<number>(0)

  return {
    columns,
    tableData,
    total,
    handleEdit
  }
}
